<?php
/**
 * Billy-Montigny functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Billy-Montigny
 */

if ( ! function_exists( 'bm_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function bm_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Billy-Montigny, use a find and replace
		 * to change 'billy-montigny' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'billy-montigny', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_image_size( 'bm-header-logo', 400, 400 );
		add_image_size( 'bm-featured-image', 1170, 9999 );
		add_image_size( 'bm-featured-image-home', 380, 9999 );
		add_image_size( 'bm-featured-image-event', 110, 110 );

		// This theme uses wp_nav_menu() in two locations.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'billy-montigny' ),
			'footer'  => esc_html__( 'Footer', 'billy-montigny' )
		) );

		/**
		 * Add support for core custom logo.
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 144,
			'width'       => 400,
			'flex-height' => true,
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, icons, and column width.
		 */
		add_editor_style( array(
			'assets/css/main.css',
			'assets/css/editor-style.css'
		) );
	}
endif;

add_action( 'after_setup_theme', 'bm_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function bm_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'bm_content_width', 640 );
}

add_action( 'after_setup_theme', 'bm_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bm_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'billy-montigny' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'billy-montigny' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer', 'billy-montigny' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here to appear in your footer.', 'billy-montigny' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}

add_action( 'widgets_init', 'bm_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function bm_scripts() {
	$suffix = is_rtl() ? '-rtl' : '';
	$min_suffix = WP_DEBUG ? '' : '.min';

	// Load our main stylesheet.
	wp_enqueue_style( 'billy-montigny-main',
		get_theme_file_uri( '/assets/css/main' . $suffix . $min_suffix . '.css' ),
		array(), null
	);

	// Theme stylesheet.
	wp_enqueue_style( 'billy-montigny-style',
		get_stylesheet_uri(), array( 'billy-montigny-main' ), null
	);

	// Load Foundation and our scripts.
	wp_enqueue_script( 'billy-montigny-scripts',
		get_theme_file_uri( '/assets/js/app' . $min_suffix . '.js' ),
		array( 'jquery' ), null, true
	);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'bm_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Custom functions for media display using Foundation components.
 */
// require get_template_directory() . '/inc/media.php';

/**
 * Filters and custom functions to modify some widgets.
 */
require get_template_directory() . '/inc/widgets.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
