<?php
/**
 * Custom functions for media display using Foundation components.
 *
 * @require Foundation.Interchange
 * @require Foundation.Orbit
 *
 * @package Billy-Montigny
 */

/**
 * A helper function to calculate the image sources to include in a
 * ‘data-interchange’ attribute to use with Foundation.
 *
 * Note that it allows to have a responsive background image waiting that
 * it's included to Wordpress core.
 *
 * @param array  $size_array    Array of width and height values in pixels (in
 *                              that order).
 * @param string $image_src     The 'src' of the image.
 * @param array  $image_meta    The image meta data as returned by 
 *                              'wp_get_attachment_metadata()'.
 * @param int    $attachment_id Optional. The image attachment ID to pass to
 *                              the filter. Default 0.
 *
 * @return string|bool          The 'srcset' attribute value. False on error
 *                              or when only one source exists.
 */
function zf_calculate_image_interchange( $size_array, $image_src, $image_meta, $attachment_id = 0 ) {
	// Calculate the image sources with Wordpress helper.
	$srcsets = wp_calculate_image_srcset( $size_array, $image_src, $image_meta, $attachment_id );

	if ( ! $srcsets ) {
		return false;
	}

	$srcsets = explode ( ', ', $srcsets );

	$interchange = '';
	$breakpoints = array();

	// Iterate over image sources to get the better one.
	foreach ( $srcsets as $srcset ) {
		list($src, $width) = explode( ' ', $srcset, 2 );
		$width = absint( rtrim( $width, 'w' ) );

		if ( $width >= 1920 ) {
			$breakpoint = 'xlarge';
		} elseif ( $width >= 1440 ) {
			$breakpoint = 'large';
		} elseif ( $width >= 1024 ) {
			$breakpoint = 'medium';
		} elseif ( $width >= 640 ) {
			$breakpoint = 'small';
		} else {
			continue;
		}

		// Choose the image with the closest size.
		if ( ! isset( $breakpoints[$breakpoint] )
		     || $breakpoints[$breakpoint][0] > $width ) {
			$breakpoints[$breakpoint] = array( $width, $src );
		}
	}

	if ( ! isset( $breakpoints ) ) {
		return false;
	}

	$breakpoint = null;

	// Construct the 'data-interchange' value from breakpoints
	// in order to have each size displaying well.
	foreach ( array( 'small', 'medium', 'large', 'xlarge' ) as $size ) {
		if ( ! $breakpoint ) {
			$breakpoint = $size;
		}

		if ( ! isset( $breakpoints[$size] ) ) {
			continue;
		}

		$src = $breakpoints[$size][1];
		$interchange .= '[' . $src . ', ' . $breakpoint . '], ';

		// Use the next size as breakpoint.
		$breakpoint = null;
	}

	return rtrim( $interchange, ', ' );
}

/**
 * Get an HTML div element representing an image attachment as background.
 *
 * @param int          $attachment_id Image attachment ID.
 * @param string|array $attr          Optional. Attributes for the image
 *                                    markup. Default empty.
 *
 * @return string HTML div element or empty string on failure.
 */
function zf_get_attachment_image_interchange( $attachment_id, $attr = '' ) {
	$html = '';
	$image = wp_get_attachment_image_src( $attachment_id, 'full' );
	if ( $image ) {
		list($src, $width, $height) = $image;
		$default_attr = array();

		$attr = wp_parse_args( $attr, $default_attr );

		// Generate 'data-interchange' if not already present.
		if ( empty( $attr['data-interchange'] ) ) {
			$image_meta = wp_get_attachment_metadata( $attachment_id );

			if ( is_array( $image_meta ) ) {
				$size_array = array( absint( $width ), absint( $height ) );
				$interchange = zf_calculate_image_interchange( $size_array, $src, $image_meta, $attachment_id );

				if ( $interchange ) {
					$attr['data-interchange'] = $interchange;
				} else {
					$attr['style'] = 'background-image: url(' . $src . ')';
				}
			}
		}

		$attr = array_map( 'esc_attr', $attr );
		$html = '<div';
		foreach ( $attr as $name => $value ) {
			$html .= " {$name}=" . '"' . $value . '"';
    }
		$html .= '></div>';
	}

	return $html;
}

/**
 * Transform a gallery into Orbit caroussel.
 *
 * @param string $output   The gallery output. Default empty.
 * @param array  $attr     Attributes of the gallery shortcode.
 * @param int    $instance Unique numeric ID of this gallery shortcode instance.
 *
 * Additionnal attributes of the gallery shortcode:
 * 
 *   @type bool   $orbit       Weither to enable Orbit caroussel.
 *   @type string $label       The caroussel label for assistive technology.
 *   @type bool   $caption     Weither the image caption should be shown.
 *   @type bool   $cover       Weither the image should cover the region.
 *   @type bool   $bullets     Show the bullets for navigation.
 *   @type bool   $nav_buttons Show the navigation buttons.
 *
 * @return string HTML gallery using Orbit.
 */
function zf_orbit_gallery( $output, $attr, $instance ) {
	if ( empty( $attr['orbit'] ) || ! wp_validate_boolean( $attr['orbit'] ) ) {
		return '';
	}

	$post = get_post();
	$atts = shortcode_atts( array(
		'order'       => 'ASC',
		'orderby'     => 'menu_order ID',
		'id'          => $post ? $post->ID : 0,
		'size'        => 'thumbnail',
		'include'     => '',
		'exclude'     => '',
		'link'        => '',
		'label'       => '',
		'caption'     => true,
		'cover'       => false,
		'bullets'     => false,
		'nav_buttons' => false
	), $attr, 'gallery' );

	$id = intval( $atts['id'] );

	// récupère les images attachées
	if ( ! empty( $atts['include'] ) ) {
		$_attachments = get_posts( array(
			'include' => $atts['include'],
			'post_status' => 'inherit',
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'order' => $atts['order'],
			'orderby' => $atts['orderby']
		) );
		
		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}
	} elseif ( ! empty( $atts['exclude'] ) ) {
		$attachments = get_children( array(
			'post_parent' => $id,
			'exclude' => $atts['exclude'],
			'post_status' => 'inherit',
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'order' => $atts['order'],
			'orderby' => $atts['orderby']
		) );
	} else {
		$attachments = get_children( array(
			'post_parent' => $id,
			'post_status' => 'inherit',
			'post_type' => 'attachment',
			'post_mime_type' => 'image',
			'order' => $atts['order'],
			'orderby' => $atts['orderby']
		) );
	}

	if ( empty( $attachments ) ) {
		return '';
	}

	// récupère et formatte les arguments
	$label = wptexturize( $atts['label'] );
	$caption = wp_validate_boolean( $atts['caption'] );
	$cover = wp_validate_boolean( $atts['cover'] );
	$bullets = wp_validate_boolean( $atts['bullets'] );
	$nav_buttons = wp_validate_boolean( $atts['nav_buttons'] );

	// définis les attributs pour Orbit
	// TODO: data-pause-on-hover
	$orbit_attr = array( 'data-orbit', 'data-pause-on-hover="false"' );
	if ( ! $bullets ) {
		$orbit_attr[] = 'data-bullets="false"';
	}
	if ( ! $nav_buttons ) {
		$orbit_attr[] = 'data-nav-buttons="false"';
	}
	if ( $label ) {
		$orbit_attr[] = 'aria-label="'. $label . '"';
	}

	// construit le conteneur
	$output = '<div class="orbit" role="region" ' . join( ' ', $orbit_attr ) . '>';
	if ( $cover ) {
		$output .= '<ul class="orbit-container expanded">';
	} else {
		$output .= '<ul class="orbit-container">';
	}

	foreach ( $attachments as $id => $attachment ) {

		// construit le tag pour l'image
		$attr = array( 'class' => 'orbit-image' );
		if ( $cover ) {
			$image_output = zf_get_attachment_image_interchange ( $id, $attr );
		} else {
			$image_output = wp_get_attachment_image( $id, $atts['size'], false, $attr );
		}

		// ajoute l'image au caroussel
		$output .= '<li class="orbit-slide">' . $image_output;

		// ajoute la légende
		if ( $caption && trim($attachment->post_excerpt) ) {
			$output .= '<figcaption class="orbit-caption">' . wptexturize($attachment->post_excerpt) . '</figcaption>';
		}

		$output .= '</li>';
	}

	// ferme le conteneur
	$output .= '</ul></div>';

	return $output;
}

add_filter( 'post_gallery', 'zf_orbit_gallery', 10, 3 );
