<?php
/**
 * Functions which enhance the theme by hooking into WordPress.
 *
 * @package Billy-Montigny
 */

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function bm_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}

add_action( 'wp_head', 'bm_pingback_header' );

/**
 * Show kitchen sink by default.
 *
 * @param $args
 *
 * @return mixed
 */
function bm_unhide_kitchensink( $args ) {
	$args['wordpress_adv_hidden'] = false;

	return $args;
}

add_filter( 'tiny_mce_before_init', 'bm_unhide_kitchensink' );

/**
 * Unregister some Core Widgets.
 */
function bm_default_widgets() {
	unregister_widget( 'WP_Widget_Pages' );
	unregister_widget( 'WP_Widget_Calendar' );
	unregister_widget( 'WP_Widget_Archives' );
//	unregister_widget( 'WP_Widget_Links' );
	unregister_widget( 'WP_Widget_Meta' );
//	unregister_widget( 'WP_Widget_Search' );
	unregister_widget( 'WP_Widget_Recent_Comments' );
	unregister_widget( 'WP_Widget_RSS' );
	unregister_widget( 'WP_Widget_Tag_Cloud' );
}

add_action( 'widgets_init', 'bm_default_widgets', 10 );

/**
 * Callback function to filter the MCE settings.
 *
 * @param $buttons
 *
 * @return mixed
 */
function bm_mce_buttons( $buttons ) {
	array_unshift( $buttons, 'styleselect' );

	return $buttons;
}

add_filter( 'mce_buttons_2', 'bm_mce_buttons' );

/**
 * Add custom formats to TinyMCE.
 *
 * @param $init_array
 *
 * @return mixed
 */
function bm_insert_formats( $init_array ) {
	$style_formats = array(
		array(
			'title'   => esc_html__( 'Button', 'billy-montigny' ),
			'block'   => 'a',
			'classes' => 'button',
			'wrapper' => true,
		),
		array(
			'title'   => esc_html__( 'Callout', 'billy-montigny' ),
			'block'   => 'div',
			'classes' => 'callout',
			'wrapper' => true,
		)
	);
	$init_array['style_formats'] = json_encode( $style_formats );

	return $init_array;
}

add_filter( 'tiny_mce_before_init', 'bm_insert_formats' );

/**
 * Renames sticky class.
 *
 * @param $classes
 *
 * @return array
 */
function bm_change_sticky_class( $classes ) {
	if ( in_array( 'sticky', $classes, true ) ) {
		$classes   = array_diff( $classes, array( 'sticky' ) );
		$classes[] = 'sticky-post';
	}

	return $classes;
}

add_filter( 'post_class', 'bm_change_sticky_class' );

/**
 * Filters the Read More link text.
 *
 * It simply wraps it inside a <div> container.
 *
 * @param string $more_link_element Read More link element.
 *
 * @return string
 */
function bm_the_content_more_link( $more_link_element ) {
	return '<div class="read-more">' . trim( $more_link_element ) . '</div>';
}

add_filter( 'the_content_more_link', 'bm_the_content_more_link' );

/**
 * Filters the CSS class(es) applied to a menu list element.
 *
 * It adds Foundation classes for a Dropdown sub-menu.
 *
 * @param array $classes The CSS classes that are applied to the menu
 *                       `<ul>` element.
 *
 * @return array
 */
function bm_nav_menu_submenu_css_class( $classes ) {
	return array_merge( $classes, array( 'vertical', 'menu' ) );
}

add_filter( 'nav_menu_submenu_css_class', 'bm_nav_menu_submenu_css_class' );

/**
 * Filters the CSS class(es) applied to a menu item's list item element.
 *
 * @param array $classes The CSS classes that are applied to the menu
 *                       item's `<li>` element.
 *
 * @return array
 */
function bm_nav_menu_css_class( $classes ) {
	if ( in_array( 'menu-item-has-children', $classes ) ) {
		// prevents flash of unstyled content
		$classes[] = 'is-dropdown-submenu-parent';
	}

	return $classes;
}

add_filter( 'nav_menu_css_class', 'bm_nav_menu_css_class' );

/**
 * Filters the HTML list content for navigation menus.
 *
 * It appends a 'Home' item with an icon to the primary menu and replace
 * the 'Facebook' item from the footer menu by an icon.
 *
 * @param string   $items The HTML list content for the menu items.
 * @param stdClass $args  An object containing wp_nav_menu() arguments.
 *
 * @return string
 */
function bm_nav_menu_items( $items, $args ) {
	if ( 'primary' === $args->theme_location ) {
		$home_item = '<li class="show-for-medium';
		if ( is_home() ) {
			$home_item .= ' current-menu-item';
		}
		$home_item .= '">' .
			'<a href="' . esc_url( home_url( '/' ) ) . '">' .
				'<span class="icon icon-home" aria-hidden="true"></span>' .
				'<span class="show-for-sr">Accueil</span>' .
			'</a></li>';

		return $home_item . $items;
	} else if ( 'footer' === $args->theme_location ) {
		$fb_item = '<span class="icon icon-facebook" aria-hidden="true"></span>' .
			'<span class="show-for-sr">Facebook</span>';
		return str_replace('>Facebook<', '>' . $fb_item . '<', $items);
	}

	return $items;
}

add_filter( 'wp_nav_menu_items', 'bm_nav_menu_items', 10, 2 );
